# cf_units

[![Build Status](https://secure.travis-ci.org/SciTools/cf_units.png)](http://travis-ci.org/SciTools/cf_units)

(C) British Crown Copyright 2010 - 2015, Met Office

Units of measure as required by the Climate and Forecast (CF) metadata conventions.

Provision of a wrapper class to support Unidata/UCAR UDUNITS-2, and the
netcdftime calendar functionality.

See also: [UDUNITS-2](http://www.unidata.ucar.edu/software/udunits/udunits-2/udunits2.html)
